@@ -28,8 +28,10 @@ class Temp_File
 public:
   const boost::filesystem::path path;
 
-  Temp_File(const std::string &s): path(Temp_Path(s)) {}
-  Temp_File(const char *s): path(Temp_Path(s)) {}
+  Temp_File(const boost::filesystem::path &parent,const std::string &s):
+    path(Temp_Path(parent,s)) {}
+  Temp_File(const boost::filesystem::path &parent,const char *s):
+    path(Temp_Path(parent,s)) {}
 
   /* A separate contructor to allow you to specify which file will be
      deleted. */
