@@ -22,19 +22,20 @@
 #include "boost/filesystem/operations.hpp"
 #include <sstream>
 
-inline boost::filesystem::path Temp_Path(const std::string &s)
+inline boost::filesystem::path Temp_Path(const boost::filesystem::path &parent,
+                                         const std::string &s)
 {
   int counter(0);
 
   std::stringstream temp_stream;
-  temp_stream << s << "." << counter;
-  while(exists(boost::filesystem::path(temp_stream.str())))
+  temp_stream << s;
+  while(exists(parent/temp_stream.str()))
     {
       ++counter;
       temp_stream.str("");
       temp_stream << s << "." << counter;
     }
-  return boost::filesystem::path(temp_stream.str());
+  return boost::filesystem::path(parent/temp_stream.str());
 }
 
 #endif
