@@ -4,6 +4,7 @@
   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents
                            of the University of California
+  Copyright (C) 2005 Walter Landry
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,13 +24,16 @@
 #define ARX_DO_PATCH_HPP
 
 #include "boost/filesystem/operations.hpp"
+#include "Conflicts.hpp"
 
-extern bool do_patch(const boost::filesystem::path &patch,
-                     const boost::filesystem::path &source,
-                     const bool &reverse,
-                     const bool &delete_removed);
+extern Conflicts do_patch(const boost::filesystem::path &patch,
+                          const boost::filesystem::path &source,
+                          const bool &reverse,
+                          const bool &delete_removed,
+                          bool apply_content_patches=true,
+                          bool record_missing=true);
 
-extern bool do_patch(const boost::filesystem::path &patch,
+extern void do_patch(const boost::filesystem::path &patch,
                      const boost::filesystem::path &source,
                      const bool &reverse);
 
