@@ -1,4 +1,5 @@
-/* Perform a merge of a branch with its sibling
+/* Perform a merge of a branch with its sibling.  Returns whether the
+   merge produced conflicts.
 
   Copyright (C) 2001, 2002, 2003 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry
@@ -24,9 +25,13 @@
 
 #include "boost/filesystem/operations.hpp"
 #include "Parsed_Name.hpp"
+#include "Merge_Algo.hpp"
+#include "Conflicts.hpp"
 
-extern void merge_branches(const Parsed_Name &main, const Parsed_Name &sibling,
-                           const boost::filesystem::path &sibling_path,
-                           const bool &delete_removed);
-
+extern Conflicts merge_branches(const Parsed_Name &tree,
+                                const Parsed_Name &sibling,
+                           Parsed_Name &ancestor,
+                           const boost::filesystem::path &tree_path,
+                           const Merge_Algo &merge_algo,
+                           const bool &delete_removed,const bool &update);
 #endif
