@@ -1,8 +1,9 @@
-/* Get the default branch for the current project tree.
+/* Get or set the default branch for the current project tree.
 
    Copyright (C) 2001, 2002 Tom Lord
    Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                   University of California
+   Copyright (C) 2005 Walter Landry
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -26,6 +27,8 @@
 #include "get_option_from_file.hpp"
 #include "tree_root.hpp"
 #include "Parsed_Name.hpp"
+#include "set_option_in_file.hpp"
+#include "valid_package_name.hpp"
 
 inline Parsed_Name tree_branch(const boost::filesystem::path &tree_directory)
 {
@@ -33,4 +36,12 @@ inline Parsed_Name tree_branch(const boost::filesystem::path &tree_directory)
                                           / "_arx/++default-branch"));
 }
 
+inline void tree_branch(const boost::filesystem::path &tree_directory,
+                        const Parsed_Name &name)
+{
+  valid_package_name(name,Branch);
+  set_option_in_file(tree_root(tree_directory)
+                     / "_arx/++default-branch",name.complete_branch());
+}
+
 #endif
